==> zio-aws-computeoptimizer_3-5.17.124.2-sources.jar: zio/aws/computeoptimizer/model/ExportEbsVolumeRecommendationsResponse.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.JobId
import scala.jdk.CollectionConverters.*
final case class ExportEbsVolumeRecommendationsResponse(
    jobId: Option[JobId] = None,
    s3Destination: Option[zio.aws.computeoptimizer.model.S3Destination] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse = {
    import ExportEbsVolumeRecommendationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(s3Destination.map(value => value.buildAwsValue()))(
        _.s3Destination
      )
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly =
    zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
      .wrap(buildAwsValue())
}
object ExportEbsVolumeRecommendationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse =
      zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse(
        jobId.map(value => value),
        s3Destination.map(value => value.asEditable)
      )
    def jobId: Option[JobId]
    def s3Destination
        : Option[zio.aws.computeoptimizer.model.S3Destination.ReadOnly]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getS3Destination: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.S3Destination.ReadOnly
    ] = AwsError.unwrapOptionField("s3Destination", s3Destination)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ) extends zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly {
    override val jobId: Option[JobId] = scala
      .Option(impl.jobId())
      .map(value => zio.aws.computeoptimizer.model.primitives.JobId(value))
    override val s3Destination
        : Option[zio.aws.computeoptimizer.model.S3Destination.ReadOnly] = scala
      .Option(impl.s3Destination())
      .map(value => zio.aws.computeoptimizer.model.S3Destination.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ): zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.17.195.1-sources.jar: zio/aws/computeoptimizer/model/ExportEbsVolumeRecommendationsResponse.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.JobId
import scala.jdk.CollectionConverters.*
final case class ExportEbsVolumeRecommendationsResponse(
    jobId: Optional[JobId] = Optional.Absent,
    s3Destination: Optional[zio.aws.computeoptimizer.model.S3Destination] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse = {
    import ExportEbsVolumeRecommendationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(s3Destination.map(value => value.buildAwsValue()))(
        _.s3Destination
      )
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly =
    zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
      .wrap(buildAwsValue())
}
object ExportEbsVolumeRecommendationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse =
      zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse(
        jobId.map(value => value),
        s3Destination.map(value => value.asEditable)
      )
    def jobId: Optional[JobId]
    def s3Destination
        : Optional[zio.aws.computeoptimizer.model.S3Destination.ReadOnly]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getS3Destination: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.S3Destination.ReadOnly
    ] = AwsError.unwrapOptionField("s3Destination", s3Destination)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ) extends zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly {
    override val jobId: Optional[JobId] = zio.aws.core.internal
      .optionalFromNullable(impl.jobId())
      .map(value => zio.aws.computeoptimizer.model.primitives.JobId(value))
    override val s3Destination
        : Optional[zio.aws.computeoptimizer.model.S3Destination.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3Destination())
        .map(value => zio.aws.computeoptimizer.model.S3Destination.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse
  ): zio.aws.computeoptimizer.model.ExportEbsVolumeRecommendationsResponse.ReadOnly =
    new Wrapper(impl)
}
